Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigOrDefault ¶
func ConfigOrDefault[T comparable](conf, def T) T
ConfigOrDefault will return a value if it is non-zero (or empty), or a default value
Types ¶
type Event ¶
Event is sent from the per-ticker goroutine to a common channel when the ticker interval ticks over
type Ticker ¶
type Ticker struct {
// contains filtered or unexported fields
}
Ticker holds callbacks to be invoked at the specified period (e.g every 5 minutes)
Click to show internal directories.
Click to hide internal directories.